FallibleHexd

Struct FallibleHexd 

pub struct FallibleHexd<R: ReadBytes> { /* private fields */ }
A fallible variant of Hexd that surfaces errors from the underlying reader.

Implementations

Source

impl<R: ReadBytes> FallibleHexd<R>

pub fn new(reader: R) -> Self

Construct a new Hexd instance with the given reader and default options.

pub fn new_with_options(reader: R, options: HexdOptions) -> Self

Construct a new Hexd instance with the given reader and options.

pub fn dump(self) -> Result<(), R::Error>

Print a hexdump to stdout.

use hxd::IntoFallibleHexd;
use std::fs::OpenOptions;

let f = OpenOptions::new().read(true).open("file.txt").unwrap();

f.hexd().dump().expect("could not read file"); // print a hexdump
pub fn dump_err(self) -> Result<(), R::Error>

Print a hexdump to stderr.

use hxd::IntoFallibleHexd;
use std::fs::OpenOptions;

let f = OpenOptions::new().read(true).open("file.txt").unwrap();

f.hexd().dump_err().expect("could not read file"); // print a hexdump to stderr
pub fn dump_to<W: WriteHexdump + Default>(self) -> Result<W::Output, R::Error>

Construct a default instance of W and write a hexdump to it, returning its output.

use hxd::IntoFallibleHexd;
use std::fs::OpenOptions;

let f = OpenOptions::new().read(true).open("file.txt").unwrap();

let dump = f.hexd().dump_to::<String>().expect("could not read file");
pub fn dump_into<W: WriteHexdump>( self, writer: W, ) -> Result<W::Output, R::Error>

Write a hexdump to an instance of W and return its output.

use hxd::IntoFallibleHexd;
use std::fs::OpenOptions;

let f = OpenOptions::new().read(true).open("file.txt").unwrap();

let v: Vec<String> = Vec::new();
let dump = f.hexd().dump_into(v).expect("could not read file");
pub fn dump_io<W: Write>( self, write: W, ) -> Result<(), ReadWriteError<R::Error, Error>>

Write a hexdump to an object that is Write. The object is wrapped in a BufWriter for improved performance.

use hxd::{IntoFallibleHexd, ReadWriteError};
use std::fs::OpenOptions;

let src = OpenOptions::new().read(true).open("file.txt").unwrap();

let f = OpenOptions::new()
    .write(true)
    .create(true)
    .open("hexdump.txt")
    .unwrap();

src.hexd().dump_io(f).map_err(|err| match err {
    ReadWriteError::Read(e) => panic!("could not read file: {:?}", e),
    ReadWriteError::Write(e) => panic!("could not write to file: {:?}", e),
});
pub fn dump_io_unbuffered<W: Write>( self, write: W, ) -> Result<(), ReadWriteError<R::Error, Error>>

Write a hexdump to an object that is Write. Unlike Self::dump_io, this method does not wrap the object in a BufWriter.

use hxd::{IntoFallibleHexd, ReadWriteError};
use std::fs::OpenOptions;

let src = OpenOptions::new().read(true).open("file.txt").unwrap();

let f = OpenOptions::new()
    .write(true)
    .create(true)
    .open("hexdump.txt")
    .unwrap();

src.hexd().dump_io_unbuffered(f).map_err(|err| match err {
    ReadWriteError::Read(e) => panic!("could not read file: {:?}", e),
    ReadWriteError::Write(e) => panic!("could not write to file: {:?}", e),
});